@@ -2,7 +2,7 @@ import pandas as pd
 import numpy as np
 import seaborn as sns
 import matplotlib.pyplot as plt
-from .private_func import _get_report, _get_report_composite
+from .private_func import _get_report, _get_report_composite, _get_report2
 import warnings
 import datetime
 import chinese_calendar as cc
@@ -54,6 +54,25 @@ def get_report(delta, ret, long_short_split=True):
         return pd.concat([report_all, report_long, report_short, report_sub])
 
 
+def get_report2(pnl):
+    """
+    pnl: pd.Series with DatatimeIndex
+    """
+    if not (isinstance(pnl, pd.Series)):
+        print('indicator and pnl must be pd.Series')
+        return
+
+    if not (isinstance(pnl.index, pd.core.indexes.datetimes.DatetimeIndex)):
+        print('index of indicator and pnl must be pd.core.indexes.datetimes.DatetimeIndex')
+        return
+
+    report_all = _get_report2(pnl).rename('All').to_frame().T
+    report_sub = pnl.groupby(by=pnl.index.to_series().apply(lambda x: x.year)) \
+        .apply(lambda x: _get_report2(x)).unstack()
+
+    return pd.concat([report_all, report_sub])
+
+
 def get_composite_report(delta, ret, long_short_split=True):
     """
     delta: pd.DataFrame with DatatimeIndex
@@ -181,6 +200,56 @@ def get_pnl_plot(delta, ret, fig_return=False, alpha=False, **kwargs):
     return
 
 
+def get_pnl_plot2(pnl, fig_return=False, **kwargs):
+    """
+    pnl: pd.Series with DatatimeIndex
+    """
+    if not (isinstance(pnl, pd.Series)):
+        print('and pnl must be pd.Series')
+        return
+
+    if not (isinstance(pnl.index, pd.core.indexes.datetimes.DatetimeIndex)):
+        print('index of pnl must be pd.core.indexes.datetimes.DatetimeIndex')
+        return
+
+    report_all = _get_report2(pnl)
+
+    fig = plt.figure(figsize=(20, 12))
+
+    ax1 = plt.subplot2grid((3, 1), (0, 0), rowspan=2)
+    ax2 = plt.subplot2grid((3, 1), (2, 0))
+
+    # pnl
+
+    day_pnl = pnl.groupby(by=pnl.index.to_series().apply(lambda x: x.date())).sum()
+    DD_ss = day_pnl.cumsum() - day_pnl.cumsum().expanding(0).max()
+
+    day_pnl.cumsum().plot(ax=ax1, label='Strategy')
+
+    ax1.set_title('PnL={} Sharpe={} Calmar={} WR={:.2f}'.format(
+        report_all.loc['PnL'], report_all.loc['Sharpe'],
+        report_all.loc['Calmar'], report_all.loc['WR']
+    ))
+    ax1.set_ylabel('PnL')
+    ax1.legend(loc=2)
+    ax1.set_xlabel('')
+    ax1.grid()
+
+    DD_ss.plot(ax=ax2, c='r')
+    ax2.set_title('MDD={} MDDD={} Worst={:.2f}'.format(
+        report_all.loc['MDD'], report_all.loc['MDDD'], report_all.loc['Worst']
+    ))
+    ax2.set_ylabel('Drawdown')
+    ax2.set_xlabel('Date')
+    ax2.grid()
+
+    plt.show()
+    if fig_return:
+        return fig
+
+    return
+
+
 def get_composite_pnl_plot(delta, ret, fig_return=False, alpha=False, **kwargs):
     """
     Multi-Assets PnL
@@ -362,7 +431,7 @@ def round_test(delta, close, adj_close, BPV, mult=1e4, fee_rate=3e-4, vol_limit=
     new_pot = (new_pnl.sum().sum() / (new_vol.diff() * BPV * close).abs().sum().sum()) * 1e4
 
     def _sharpe(m):
-        return m.mean() / m.std() * 16.0
+        return m.mean() / m.std() * np.sqrt(250)
 
     data_pnl = pd.concat([
         og_sum_pnl.rename('Orginal Delta: PnL={} Sharpe={:.2f} PoT={:.2f}'. \
