@@ -41,13 +41,13 @@ class simpletest():
 
     def simple_pnl(self, x, y,
                    ax=None, st_plot=True, data_return=True,
-                   sign=True, med=True, peak=True,
+                   sign=True, val=True, peak=True,
                    bt_plot=False, **kwargs):
         """
         x: pd.Series
         y: pd.Series
         Sign-Trade: factor >(<) 0 -> indicator = 1(-1) * sign(corr)
-        Med-Trade: factor >(<) factor_medium -> indicator = 1(-1) * sign(corr)
+        Val-Trade: indicator =  factor/factor.abs.mean * 100
         Peak-Trade: factor >(<) cdf_peak_factor_val -> indicator = 1(-1) * sign(corr)
         """
 
@@ -102,10 +102,9 @@ class simpletest():
                 output['pnl_sign'] = sum_pnl1
                 output['delta_sign'] = indicator1
 
-        if med:
-            factor_mid = np.median(factor)
-            indicator2 = factor.apply(lambda m: 1 if m >= factor_mid else -1) * 100 * np.sign(corr)
-            label2 = 'Med-Trade: '
+        if val:
+            indicator2 = factor/factor.abs().mean() * 100  * np.sign(corr)
+            label2 = 'Val-Trade: '
 
             pnl2 = ret * indicator2
             sum_pnl2 = pnl2.cumsum()
@@ -127,8 +126,8 @@ class simpletest():
                               .format(pnl_y2, sharpe2, pot2))
 
             if data_return:
-                output['pnl_med'] = sum_pnl2
-                output['delta_med'] = indicator2
+                output['pnl_val'] = sum_pnl2
+                output['delta_val'] = indicator2
 
         if peak:
             peak_val = self.get_cdf_peak(factor, ret)
@@ -164,7 +163,11 @@ class simpletest():
             (y.cumsum() * 100.0).dropna().plot(ax=ax,
                                                label='Asset Cumulative Return', ls=':', c='k',
                                                alpha=0.5)
-            ax.set_title('Simple Time-Series Test')
+            if 'title' in kwargs:
+                title = kwargs.pop('title')
+                ax.set_title(f'Simple Time-Series Test (info: {str(title)})')
+            else:
+                ax.set_title('Simple Time-Series Test')
             ax.set_ylabel('PnL')
             ax.set_xlabel('Date')
             ax.legend()
@@ -174,7 +177,7 @@ class simpletest():
             if sign:
                 get_pnl_plot(indicator1, ret, **kwargs)
 
-            if med:
+            if val:
                 get_pnl_plot(indicator2, ret, **kwargs)
 
             if peak:
@@ -522,13 +525,6 @@ class simpletest():
 
         fig = plt.figure(figsize=figsize)
 
-        if 'title' in kwargs:
-            title = kwargs.pop('title')
-            ax = plt.gca()
-            ax.set_title(str(title))
-            _ = ax.set_xticks([])
-            _ = ax.set_yticks([])
-
         Y = pd.concat([y.rolling(i).sum().shift(-i + 1).rename(str(i)) \
                        for i in range(1, markout_periods + 1)], axis=1)
 
@@ -554,10 +550,10 @@ class simpletest():
         else:
             sign = True
 
-        if 'med' in kwargs:
-            med = kwargs.pop('med')
+        if 'val' in kwargs:
+            val = kwargs.pop('val')
         else:
-            med = True
+            val = True
 
         if 'peak' in kwargs:
             peak = kwargs.pop('peak')
@@ -565,8 +561,12 @@ class simpletest():
             peak = True
 
         ax5 = plt.subplot2grid((3, 2), (2, 0), colspan=2, fig=fig)
+        if 'title' in kwargs:
+            title = kwargs.pop('title')
+        else:
+            title = ''
         self.simple_pnl(x, y, ax=ax5, st_plot=True, bt_plot=False,
-                        sign=sign, med=med, peak=peak)
+                        sign=sign, val=val, peak=peak, title=title)
         plt.show()
 
         if fig_return:
